/***************************************************************************/
/*                               COMPAT.H v1.0                             */
/***************************************************************************/

                     /* IPv4 packet header */
struct ip2 {  
             u_char  ip_hl:4,   /* Longitud cabecera en grupos de 32 bits */
                      ip_v:4;   /* Version de IP                          */
             u_char   ip_tos;   /* Tipo de servicio                       */
              short   ip_len;   /* Longitud total incluyendo datos        */
            u_short    ip_id;   /* Identificador paquete IP               */
              short   ip_off;   /* Offset si fragmentacion                */
             u_char   ip_ttl;   /* Time To Live                           */
             u_char     ip_p;   /* Protocolo del campo de datos           */
            u_short   ip_sum;   /* Checksum                               */
             struct   in_addr ip_src, /* Origen       */
                      ip_dst;         /* Destino      */
          };


                       /* ICMP packet header */
struct icmp2 {
              u_char	icmp_type;
              u_char	icmp_code;
              u_short   icmp_cksum;
              union {
                       u_char ih_pptr;
                       struct in_addr ih_gwaddr;
                       struct ih_idseq {
                                         n_short  icd_id;
                                         n_short  icd_seq;
                                       } ih_idseq;
                       int ih_void;
                       struct ih_pmtu  {
                                         n_short ipm_void;    
                                         n_short ipm_nextmtu;
                                       } ih_pmtu;
                    } icmp_hun;
              union {
                      struct id_ts {
                                      n_time its_otime;
                                      n_time its_rtime;
                                      n_time its_ttime;
                                   } id_ts;
                      struct id_ip {
                                      struct ip2 idi_ip;
                                   } id_ip;
                      u_long  id_mask;
                      char  id_data[1];
                    } icmp_dun;
            }; 


#define	icmp_pptr    icmp_hun.ih_pptr
#define	icmp_gwaddr  icmp_hun.ih_gwaddr
#define	icmp_id	     icmp_hun.ih_idseq.icd_id
#define	icmp_seq     icmp_hun.ih_idseq.icd_seq
#define	icmp_void    icmp_hun.ih_void
#define	icmp_pmvoid  icmp_hun.ih_pmtu.ipm_void
#define	icmp_nextmtu icmp_hun.ih_pmtu.ipm_nextmtu
#define	icmp_otime   icmp_dun.id_ts.its_otime
#define	icmp_rtime   icmp_dun.id_ts.its_rtime
#define	icmp_ttime   icmp_dun.id_ts.its_ttime
#define	icmp_ip	     icmp_dun.id_ip.idi_ip
#define	icmp_mask    icmp_dun.id_mask
#define icmp_data    icmp_dun.id_data


                   /* UDP packet header */
struct udp_hdr {
                 u_short   source;  /* Puerto origen  */
                 u_short     dest;  /* Puerto destino */
                   short  uh_ulen;  /* Longitud       */
                 u_short   uh_sum;  /* Checksum       */
               };


                   /* TCP packet header */
struct tcp_hdr {
                 u_short source;   /* Puerto origen       */
                 u_short   dest;   /* Puerto destino      */
                 u_long     seq;   /* Numero de secuencia */
               };


                   /* ICMP ECHO packet header */
struct echo_hdr {
                  u_char  type;
                  u_char  code;
                  u_short cksum;
                  u_short id;
                  u_short seq;
               };

                                             
               /* To use as the ICMP packet data field */
union data_hdr {
                  struct tcp_hdr  cab_tcp;
                  struct udp_hdr  cab_udp;
                  struct echo_hdr cab_echo;
               };


#define TCAB_IP      sizeof(struct ip2)
#define TCAB_ICMP    sizeof(struct icmp2)
#define TCAB_UDP     sizeof(struct udp_hdr)
#define TCAB_TCP     sizeof(struct tcp_hdr)
#define TCAB_ECHO    sizeof(struct echo_hdr)
#define TCAB_64DATA  sizeof(union data_hdr)

#define ICMP_DEST_UNREACH    3
#define ICMP_SOURCE_QUENCH   4
#define ICMP_REDIRECT        5
#define ICMP_ECHO            8 
#define ICMP_TIME_EXCEEDED  11

#define TTL_DFL  255
#define ICMP_ERR_DFL_TOS 0